searchNodes=[{"doc":"EctoCommons contains common validators and formatters, mainly to be used with Ecto.Changesets","ref":"EctoCommons.html","title":"EctoCommons","type":"module"},{"doc":"This module provides validators for DateTimes.You can use the following checks::is to check if a DateTime is exactly some DateTime. You can also provide a :delta option (in seconds) to specify a delta around which the DateTime is still considered identical.:before to check if a DateTime is before some DateTime:after to check if a DateTime is after some DateTimeYou can also combine the given checks for complex checks. Errors won't be stacked though, the first error encountered will be returned and subsequent checks will be skipped. If you want to check everything at once, you'll need to call this validator multiple times.Also, instead of providing a DateTime, you can also provide some special atoms::utc_now will compare the given DateTime with the DateTime at runtime, by calling DateTime.utc_now().Example:iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; # Using :is to ensure a date is identical to another date iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, is: ~U[2016-05-24 13:26:08Z]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, is: ~U[2017-05-24 13:26:08Z]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [birthdate: {&quot;should be %{is}.&quot;, [validation: :datetime, kind: :is]}], data: %{}, valid?: false&gt; # Using :is with :delta to ensure a date is near another another date iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, is: ~U[2016-05-24 13:46:08Z], delta: 3600) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 15:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, is: ~U[2016-05-24 13:26:08Z], delta: 3600) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 15:26:08Z]}, errors: [birthdate: {&quot;should be %{is}.&quot;, [validation: :datetime, kind: :is]}], data: %{}, valid?: false&gt; # Using :before to ensure date is before given date iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, before: ~U[2017-05-24 00:00:00Z]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, before: ~U[2015-05-24 00:00:00Z]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [birthdate: {&quot;should be before %{before}.&quot;, [validation: :datetime, kind: :before]}], data: %{}, valid?: false&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, before: :utc_now) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[3000-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, before: :utc_now) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[3000-05-24 13:26:08Z]}, errors: [birthdate: {&quot;should be before %{before}.&quot;, [validation: :datetime, kind: :before]}], data: %{}, valid?: false&gt; # Using :after to ensure date is after given date iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, after: ~U[2015-05-24 00:00:00Z]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[2016-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, after: ~U[2017-05-24 00:00:00Z]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[2016-05-24 13:26:08Z]}, errors: [birthdate: {&quot;should be after %{after}.&quot;, [validation: :datetime, kind: :after]}], data: %{}, valid?: false&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[3000-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, after: :utc_now) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[3000-05-24 13:26:08Z]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :utc_datetime} iex&gt; params = %{birthdate: ~U[1000-05-24 13:26:08Z]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_datetime(:birthdate, after: :utc_now) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~U[1000-05-24 13:26:08Z]}, errors: [birthdate: {&quot;should be after %{after}.&quot;, [validation: :datetime, kind: :after]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.DateTimeValidator.html","title":"EctoCommons.DateTimeValidator","type":"module"},{"doc":"","ref":"EctoCommons.DateTimeValidator.html#validate_datetime/3","title":"EctoCommons.DateTimeValidator.validate_datetime/3","type":"function"},{"doc":"This module provides validators for Dates.You can use the following checks::is to check if a Date is exactly some Date. You can also provide a :delta option (in days) to specify a delta around which the Date is still considered identical.:before to check if a Date is before some Date:after to check if a Date is after some DateYou can also combine the given checks for complex checks. Errors won't be stacked though, the first error encountered will be returned and subsequent checks will be skipped. If you want to check everything at once, you'll need to call this validator multiple times.Also, instead of providing a Date, you can also provide some special atoms::utc_today will compare the given Date with the Date at runtime, by calling Date.utc_today().Example:iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [], data: %{}, valid?: true&gt; # Using :is to ensure a date is identical to another date iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, is: ~D[2016-05-24]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, is: ~D[2017-05-24]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [birthdate: {&quot;should be %{is}.&quot;, [validation: :datetime, kind: :is]}], data: %{}, valid?: false&gt; # Using :is with :delta to ensure a date is near another another date iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-20]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, is: ~D[2016-05-24], delta: 7) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-20]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-04-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, is: ~D[2016-05-24], delta: 7) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-04-24]}, errors: [birthdate: {&quot;should be %{is}.&quot;, [validation: :datetime, kind: :is]}], data: %{}, valid?: false&gt; # Using :before to ensure date is before given date iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, before: ~D[2017-05-24]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, before: ~D[2015-05-24]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [birthdate: {&quot;should be before %{before}.&quot;, [validation: :datetime, kind: :before]}], data: %{}, valid?: false&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, before: :utc_today) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[3000-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, before: :utc_today) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[3000-05-24]}, errors: [birthdate: {&quot;should be before %{before}.&quot;, [validation: :datetime, kind: :before]}], data: %{}, valid?: false&gt; # Using :after to ensure date is after given date iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, after: ~D[2015-05-24]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[2016-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, after: ~D[2017-05-24]) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[2016-05-24]}, errors: [birthdate: {&quot;should be after %{after}.&quot;, [validation: :datetime, kind: :after]}], data: %{}, valid?: false&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[3000-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, after: :utc_today) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[3000-05-24]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{birthdate: :date} iex&gt; params = %{birthdate: ~D[1000-05-24]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_date(:birthdate, after: :utc_today) #Ecto.Changeset&lt;action: nil, changes: %{birthdate: ~D[1000-05-24]}, errors: [birthdate: {&quot;should be after %{after}.&quot;, [validation: :datetime, kind: :after]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.DateValidator.html","title":"EctoCommons.DateValidator","type":"module"},{"doc":"","ref":"EctoCommons.DateValidator.html#validate_date/3","title":"EctoCommons.DateValidator.validate_date/3","type":"function"},{"doc":"This validator is used to validate emails.Example:iex&gt; types = %{email: :string} iex&gt; params = %{email: &quot;valid.email@example.com&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_email(:email) #Ecto.Changeset&lt;action: nil, changes: %{email: &quot;valid.email@example.com&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{email: :string} iex&gt; params = %{email: &quot;@invalid_email&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_email(:email) #Ecto.Changeset&lt;action: nil, changes: %{email: &quot;@invalid_email&quot;}, errors: [email: {&quot;is not a valid email&quot;, [validation: :email]}], data: %{}, valid?: false&gt; iex&gt; types = %{email: :string} iex&gt; params = %{email: &quot;uses_a_forbidden_provider@yopmail.net&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_email(:email, reject_burner_providers: true) #Ecto.Changeset&lt;action: nil, changes: %{email: &quot;uses_a_forbidden_provider@yopmail.net&quot;}, errors: [email: {&quot;uses a forbidden provider&quot;, [validation: :email]}], data: %{}, valid?: false&gt; iex&gt; types = %{email: :string} iex&gt; params = %{email: &quot;uses_a_forbidden_provider@yopmail.net&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_email(:email, reject_burner_providers: false) #Ecto.Changeset&lt;action: nil, changes: %{email: &quot;uses_a_forbidden_provider@yopmail.net&quot;}, errors: [], data: %{}, valid?: true&gt;","ref":"EctoCommons.EmailValidator.html","title":"EctoCommons.EmailValidator","type":"module"},{"doc":"","ref":"EctoCommons.EmailValidator.html#validate_email/3","title":"EctoCommons.EmailValidator.validate_email/3","type":"function"},{"doc":"This ecto validator checks the provided value is valid using the Luhn algorithm. This is useful for credit cards and other common administrative values.Example:iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;940008659&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_luhn(:admin_id) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;940008659&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;79026515100052&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_luhn(:admin_id) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;79026515100052&quot;}, errors: [admin_id: {&quot;is not a valid code&quot;, [validation: :luhn]}], data: %{}, valid?: false&gt; iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;this is an incorrect value&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_luhn(:admin_id) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;this is an incorrect value&quot;}, errors: [admin_id: {&quot;is not a valid code&quot;, [validation: :luhn]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.LuhnValidator.html","title":"EctoCommons.LuhnValidator","type":"module"},{"doc":"","ref":"EctoCommons.LuhnValidator.html#validate_luhn/3","title":"EctoCommons.LuhnValidator.validate_luhn/3","type":"function"},{"doc":"Valide the postal code within a country context.For now, only a few countries are supported:FranceBelgiumItalySpainSwitzerlandUnited KingdomExamplesiex&gt; types = %{postal_code: :string} iex&gt; params = %{postal_code: &quot;69001&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_postal_code(:postal_code, country: &quot;fr&quot;) #Ecto.Changeset&lt;action: nil, changes: %{postal_code: &quot;69001&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{postal_code: :string} iex&gt; params = %{postal_code: &quot;1120&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_postal_code(:postal_code, country: &quot;be&quot;) #Ecto.Changeset&lt;action: nil, changes: %{postal_code: &quot;1120&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{postal_code: :string} iex&gt; params = %{postal_code: &quot;00199&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_postal_code(:postal_code, country: &quot;it&quot;) #Ecto.Changeset&lt;action: nil, changes: %{postal_code: &quot;00199&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{postal_code: :string} iex&gt; params = %{postal_code: &quot;28010&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_postal_code(:postal_code, country: &quot;es&quot;) #Ecto.Changeset&lt;action: nil, changes: %{postal_code: &quot;28010&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{postal_code: :string} iex&gt; params = %{postal_code: &quot;1211&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_postal_code(:postal_code, country: &quot;ch&quot;) #Ecto.Changeset&lt;action: nil, changes: %{postal_code: &quot;1211&quot;}, errors: [], data: %{}, valid?: true&gt;","ref":"EctoCommons.PostalCodeValidator.html","title":"EctoCommons.PostalCodeValidator","type":"module"},{"doc":"","ref":"EctoCommons.PostalCodeValidator.html#validate_postal_code/3","title":"EctoCommons.PostalCodeValidator.validate_postal_code/3","type":"function"},{"doc":"This ecto validator checks the provided value is a valid social security number for a given countryExample:iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;188037424305025&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_social_security(:admin_id, country: &quot;fr&quot;) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;188037424305025&quot;}, errors: [], data: %{}, valid?: true&gt; # Also works for temporary french social security numbers and special edge cases (corsica) iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;7 56 50 2B 233 042 82&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_social_security(:admin_id, country: &quot;fr&quot;) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;7 56 50 2B 233 042 82&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;8 12 50 97 307 437 59&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_social_security(:admin_id, country: &quot;fr&quot;) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;8 12 50 97 307 437 59&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;1 88 03 74 243 050 57&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_social_security(:admin_id, country: &quot;fr&quot;) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;1 88 03 74 243 050 57&quot;}, errors: [admin_id: {&quot;is not a valid social security number&quot;, [validation: :social_security]}], data: %{}, valid?: false&gt; iex&gt; types = %{admin_id: :string} iex&gt; params = %{admin_id: &quot;this is an incorrect value&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_social_security(:admin_id, country: &quot;fr&quot;) #Ecto.Changeset&lt;action: nil, changes: %{admin_id: &quot;this is an incorrect value&quot;}, errors: [admin_id: {&quot;is not a valid social security number&quot;, [validation: :social_security]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.SocialSecurityValidator.html","title":"EctoCommons.SocialSecurityValidator","type":"module"},{"doc":"","ref":"EctoCommons.SocialSecurityValidator.html#checksum/2","title":"EctoCommons.SocialSecurityValidator.checksum/2","type":"function"},{"doc":"","ref":"EctoCommons.SocialSecurityValidator.html#split_checksum/2","title":"EctoCommons.SocialSecurityValidator.split_checksum/2","type":"function"},{"doc":"","ref":"EctoCommons.SocialSecurityValidator.html#valid?/2","title":"EctoCommons.SocialSecurityValidator.valid?/2","type":"function"},{"doc":"","ref":"EctoCommons.SocialSecurityValidator.html#validate_social_security/3","title":"EctoCommons.SocialSecurityValidator.validate_social_security/3","type":"function"},{"doc":"This module provides validation for String / Text valuesThe following validators are available:validate_has_prefix/3 which will check if a given field is prefixed by some given fixed or dynamic stringExample:# Simple prefix iex&gt; types = %{token: :string} iex&gt; params = %{token: &quot;private|some-random-string-id&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: &quot;private&quot;) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;private|some-random-string-id&quot;}, errors: [], data: %{}, valid?: true&gt; # Prefix with separator iex&gt; types = %{token: :string} iex&gt; params = %{token: &quot;private|some-random-string-id&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: &quot;private&quot;, separator: &quot;|&quot;) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;private|some-random-string-id&quot;}, errors: [], data: %{}, valid?: true&gt; # Wrong prefix iex&gt; types = %{token: :string} iex&gt; params = %{token: &quot;private|some-random-string-id&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: &quot;provider&quot;) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;private|some-random-string-id&quot;}, errors: [token: {&quot;is not prefixed by %{prefix}.&quot;, [validation: :has_prefix]}], data: %{}, valid?: false&gt; # Correct prefix but wrong separator iex&gt; types = %{token: :string} iex&gt; params = %{token: &quot;private|some-random-string-id&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: &quot;private&quot;, separator: &quot;_&quot;) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;private|some-random-string-id&quot;}, errors: [token: {&quot;is not prefixed by %{prefix}.&quot;, [validation: :has_prefix]}], data: %{}, valid?: false&gt; # Dynamic prefix from function which is correct iex&gt; types = %{token: :string} iex&gt; params = %{token: &quot;private|some-random-string-id&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: fn _chgst, _opts -&gt; &quot;private&quot; end) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;private|some-random-string-id&quot;}, errors: [], data: %{}, valid?: true&gt; # Dynamic prefix from another changeset field iex&gt; types = %{token: :string, provider: :string} iex&gt; params = %{token: &quot;iamsvc|some-random-string-id&quot;, provider: &quot;iamsvc&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: fn chgst, _opts -&gt; Ecto.Changeset.get_field(chgst, :provider) end) #Ecto.Changeset&lt;action: nil, changes: %{provider: &quot;iamsvc&quot;, token: &quot;iamsvc|some-random-string-id&quot;}, errors: [], data: %{}, valid?: true&gt; # Dynamic prefix from another changeset field iex&gt; types = %{token: :string, provider: :string} iex&gt; params = %{token: &quot;some-random-string-id&quot;, provider: nil} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: fn chgst, _opts -&gt; Ecto.Changeset.get_field(chgst, :provider) end) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;some-random-string-id&quot;}, errors: [], data: %{}, valid?: true&gt; # Dynamic prefix from function, which fails iex&gt; types = %{token: :string} iex&gt; params = %{token: &quot;private|some-random-string-id&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_has_prefix(:token, prefix: fn _chgst, _opts -&gt; &quot;test&quot; end) #Ecto.Changeset&lt;action: nil, changes: %{token: &quot;private|some-random-string-id&quot;}, errors: [token: {&quot;is not prefixed by %{prefix}.&quot;, [validation: :has_prefix]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.StringValidator.html","title":"EctoCommons.StringValidator","type":"module"},{"doc":"","ref":"EctoCommons.StringValidator.html#validate_has_prefix/3","title":"EctoCommons.StringValidator.validate_has_prefix/3","type":"function"},{"doc":"This module provides validators for Times.You can use the following checks::is to check if a Time is exactly some Time. You can also provide a :delta option (in seconds) to specify a delta around which the Time is still considered identical.:before to check if a Time is before some Time:after to check if a Time is after some TimeYou can also combine the given checks for complex checks. Errors won't be stacked though, the first error encountered will be returned and subsequent checks will be skipped. If you want to check everything at once, you'll need to call this validator multiple times.Also, instead of providing a Time, you can also provide some special atoms::utc_now will compare the given Time with the Time at runtime, by calling Time.utc_now().Example:iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [], data: %{}, valid?: true&gt; # Using :is to ensure a time is identical to another time iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, is: ~T[12:01:01]) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, is: ~T[13:01:01]) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [meeting_start: {&quot;should be %{is}.&quot;, [validation: :time, kind: :is]}], data: %{}, valid?: false&gt; # Using :is with :delta to ensure a time is near another another time iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, is: ~T[12:15:01], delta: 900) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[13:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, is: ~T[12:01:01], delta: 900) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[13:01:01]}, errors: [meeting_start: {&quot;should be %{is}.&quot;, [validation: :time, kind: :is]}], data: %{}, valid?: false&gt; # Using :before to ensure time is before given time iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, before: ~T[13:01:01]) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, before: ~T[11:01:01]) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [meeting_start: {&quot;should be before %{before}.&quot;, [validation: :time, kind: :before]}], data: %{}, valid?: false&gt; # Using :after to ensure time is after given time iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, after: ~T[11:01:01]) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{meeting_start: :time} iex&gt; params = %{meeting_start: ~T[12:01:01]} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_time(:meeting_start, after: ~T[13:01:01]) #Ecto.Changeset&lt;action: nil, changes: %{meeting_start: ~T[12:01:01]}, errors: [meeting_start: {&quot;should be after %{after}.&quot;, [validation: :time, kind: :after]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.TimeValidator.html","title":"EctoCommons.TimeValidator","type":"module"},{"doc":"","ref":"EctoCommons.TimeValidator.html#validate_time/3","title":"EctoCommons.TimeValidator.validate_time/3","type":"function"},{"doc":"This validator is used to validate URLs.OptionsThere are some available options depending on the strictness of what you want to validate::parsable: Checks to see if the URL is parsable by :http_uri.parse/1 Erlang function. This can have issues with international URLs where it should be disabled (see tests). Defaults to enabled:empty: Checks to see if the parsed %URI{} struct is not empty (all fields set to nil). Defaults to enabled:scheme: Checks to see if the parsed %URI{} struct contains a :scheme. Defaults to enabled:host: Checks to see if the parsed %URI{} struct contains a :host. Defaults to enabled:valid_host: Does a :inet.getbyhostname/1 call to check if the host exists. Defaults to disabled:path: Checks to see if the parsed %URI{} struct contains a :path. Defaults to disabled:regexp: Tries to match URL to a regexp known to catch many unwanted URLs (see below). Defaults to disabledThe approach is not yet very satisfactory IMHO, if you have suggestions, Pull Requests are welcome :)Example:iex&gt; types = %{url: :string} iex&gt; params = %{url: &quot;https://www.example.com/&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_url(:url) #Ecto.Changeset&lt;action: nil, changes: %{url: &quot;https://www.example.com/&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{url: :string} iex&gt; params = %{url: &quot;https://www.example.com/&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_url(:url, checks: [:empty, :path, :scheme, :host]) #Ecto.Changeset&lt;action: nil, changes: %{url: &quot;https://www.example.com/&quot;}, errors: [], data: %{}, valid?: true&gt; iex&gt; types = %{url: :string} iex&gt; params = %{url: &quot;some@invalid_url&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_url(:url) #Ecto.Changeset&lt;action: nil, changes: %{url: &quot;some@invalid_url&quot;}, errors: [url: {&quot;is not a valid url&quot;, [validation: :url]}], data: %{}, valid?: false&gt; iex&gt; types = %{url: :string} iex&gt; params = %{url: &quot;Just some random text&quot;} iex&gt; Ecto.Changeset.cast({%{}, types}, params, Map.keys(types)) ...&gt; |&gt; validate_url(:url) #Ecto.Changeset&lt;action: nil, changes: %{url: &quot;Just some random text&quot;}, errors: [url: {&quot;is not a valid url&quot;, [validation: :url]}], data: %{}, valid?: false&gt;","ref":"EctoCommons.URLValidator.html","title":"EctoCommons.URLValidator","type":"module"},{"doc":"","ref":"EctoCommons.URLValidator.html#blank?/1","title":"EctoCommons.URLValidator.blank?/1","type":"function"},{"doc":"","ref":"EctoCommons.URLValidator.html#validate_url/3","title":"EctoCommons.URLValidator.validate_url/3","type":"function"},{"doc":"EctoCommons Ecto common helpers such as validators and formatters.","ref":"readme.html","title":"EctoCommons","type":"extras"},{"doc":"The package is available on hex, so it can be installed by adding ecto_commons to your list of dependencies in mix.exs:def deps do [ {:ecto_commons, &quot;~&gt; 0.1.0&quot;} ] endDocumentation is published on HexDocs and can be found at https://hexdocs.pm/ecto_commons.","ref":"readme.html#installation","title":"EctoCommons - Installation","type":"extras"},{"doc":"The package contains common ecto helpers:Changeset validatorsEctoCommon.DateValidator:validate_date(changeset, field, opts): validates an equality (with approximation), before or after a given date.EctoCommon.DateTimeValidatorvalidate_datetime(changeset, field, opts): validates an equality (with approximation), before or after a given date time.EctoCommon.TimeValidatorvalidate_time(changeset, field, opts): validates an equality (with approximation), before or after a given time.EctoCommon.EmailValidatorvalidate_email(changeset, field, opts): validates if an email is valid and if it uses a temporary inbox provider (exclude temporary emails)EctoCommon.URLValidatorvalidate_url(changeset, field, opts): validates if an URL is corrent. Multiple checks can be added from looser validation to stricter.EctoCommon.StringValidatorvalidate_has_prefix(changeset, field, opts): validates if a string starts with a given prefix. The prefix itself can depend on another field or on a dynamic value.EctoCommon.PostalCodeValidatorvalidate_postal_code(changeset, field, opts): validates postal code depending on the country. This still needs improvement to support more countries.EctoCommon.SocialSecurityValidatorvalidate_social_security(changeset, field, opts): validates social security numbers (SSN) depending on the country. This only validates french SSNs for now.EctoCommon.LuhnValidatorvalidate_luhn(changeset, field, opts): validates a string with Luhn's algorithm such as credit card numbers and other administrative codes.","ref":"readme.html#summary","title":"EctoCommons - Summary","type":"extras"},{"doc":"ecto_commons follows semantic versioning. See CHANGELOG.md for more information.","ref":"readme.html#changelog","title":"EctoCommons - Changelog","type":"extras"},{"doc":"MIT. Please see LICENSE for licensing details.","ref":"readme.html#license","title":"EctoCommons - License","type":"extras"}]